@@ -11,9 +11,9 @@ use File::chdir;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-30'; # DATE
+our $DATE = '2023-10-31'; # DATE
 our $DIST = 'App-FileSortUtils'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our %SPEC;
 
@@ -282,6 +282,7 @@ sub sort_files {
     } else {
         @sorted_files = map { ($dir eq '.' ? '' : $dir eq '/' ? '/' : "$dir/") . $_->{name} } @sorted_files;
     }
+    log_info "Sorted files: %s", \@sorted_files;
 
     [200, "OK", \@sorted_files];
 }
@@ -439,6 +440,10 @@ or, from `/somewhere/else`:
 
     % mv `newest -f ~/Downloads` .
 
+If you want to see the filename on stderr as well:
+
+    % mv `newest --verbose -f ~/Downloads` .
+
 File is deemed as newest by its mtime.
 
 Some examples:
@@ -582,7 +587,7 @@ App::FileSortUtils - Utilities related to sorting files in a directory
 
 =head1 VERSION
 
-This document describes version 0.004 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-30.
+This document describes version 0.005 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-31.
 
 =head1 DESCRIPTION
 
@@ -895,6 +900,10 @@ or, from C</somewhere/else>:
 
  % mv C<newest -f ~/Downloads> .
 
+If you want to see the filename on stderr as well:
+
+ % mv C<newest --verbose -f ~/Downloads> .
+
 File is deemed as newest by its mtime.
 
 Some examples:
